==> ulyxex.1.2.0.with-tinyMce.zip: pages/core/admin_home.php <==
<?php
/* Ulyxex version 1.2.0 *****************/
class AdminSite extends Admin {
	function __construct(){
		$this->h = New Html();
		$this->t = New Translate();
	}
	public function site_params(){
		$h = $this->h;$t = $this->t;
		if ($_SESSION['userid'] == 1){
			$query = 	"SELECT ".
							PARAMS.".*,".PAGES.".NAME".
						" FROM ".
							PARAMS.
							" INNER JOIN ".PAGES." ON ".PAGES.".ID = ".PARAMS.".PAGEID";
						" WHERE ".
							PARAMS.".ID = 1 AND ".PAGES.".ID = ".PARAMS.".PAGEID";
			$query = $this->q($query);
			$dat = $this->fetch($query);
			$_[] = $h->input("hidden","update",1);
			$_[] = $h->p($t->wr("page name in use for home is")."\"".$h->b($dat['NAME'])."\"");
			$_[] = $h->p($t->wr("select home page").$this->list_pages_select($dat['PAGEID'],"pageId"));
			$options = array("tree"=>"tree","line"=>"line","child"=>"child");
			// $_[] = $h->p($t->wr("navigation").$h->select($options,"navtype",$dat['NAVTYPE'])); // add this function later 
			$_[] = $h->input("hidden","navtype","tree");
			$_[] = $h->p($t->wr("type").$h->input("text","type",$dat['TYPEPAGE']).$t->wlr("param").$h->input("text","param",$dat['PAGEID']));
			$_[] = $h->p($t->wr("website administrator mail").$h->input("text","mail",$dat['MAIL']));
			$_[] = $h->p($h->input("submit","save",$t->w("update all")));
			$inputs = implode("",$_);
			return $h->form($inputs,"home","post","admin.php?action=admin_home");
		}
	}
	public function update_site_params(){
		if ($_POST['param']) {
			$paramId = $_POST['param'];
		} else {
			$paramId = $_POST['pageId'];
		}
		$query = "UPDATE ".PARAMS.
					" SET PAGEID = '".$this->h->word($paramId).
					"',TYPEPAGE = '".$this->h->word($_POST['type']).
					"',NAVTYPE = '".$this->h->word($_POST['navtype']).
					"',MAIL = '".$this->h->safe($_POST['mail'])."'".
				" WHERE ID = 1";
		$query = $this->q($query);
		return $this->h->h3($this->t->w("some values have been modified !"),"class='warning'");
	}
	public function list_pages_select($pageId,$name){
		$query = "SELECT ".PAGES.".ID,".PAGES.".NAME,".PAGES.".TYPEPAGE FROM ".PAGES;
		$query = $this->q($query);
		$options = array();
		while ( $line = $this->fetch($query) ){
			if ($line['ID'] == $pageId){
				$optionSelectect = "k=".$line['TYPEPAGE']."&amp;v=".$line['ID'];
				$options[$line['NAME']] = "k=".$line['TYPEPAGE']."&amp;v=".$line['ID'];
			} else {
				$options[$line['NAME']] = "k=".$line['TYPEPAGE']."&amp;v=".$line['ID'];
			}
		}
		return $this->h->select($options,$name,$optionSelectect,"onchange='fillHomeFields(this.value)'");
	}
}
?>

==> ulyxex.1.2.7.with-tinyMce.zip: pages/core/admin_home.php <==
<?php
/* Ulyxex version 1.2.7 *****************/
class AdminSite extends Admin {
	function __construct(){
		$this->h = New Html();
		$this->t = New Translate();
	}
	public function site_params(){
		$h = $this->h;$t = $this->t;
		if ($_SESSION['userid'] == 1){
			$query = 	SELECT.
							PARAMS.".*,".PAGES.".NAME".
						FROM.
							PARAMS.
							INNERJOIN.PAGES._ON_.PAGES.".ID = ".PARAMS.".PAGEID";
						WHERE.
							PARAMS.".ID = 1"._AND_.PAGES.".ID = ".PARAMS.".PAGEID";
			$query = $this->q($query);
			$dat = $this->fetch($query);
			$_[] = $h->input("hidden","update",1);
			$_[] = $h->p($t->wr("page name in use for home is").$h->b("\"".$dat['NAME']."\""));
			$options = array("tree"=>"tree","line"=>"line","child"=>"child");
			$_[] = $h->p($t->wr("navigation").$h->select($options,"navtype",$dat['NAVTYPE']));
			$_[] = $h->p($t->wr("select home page").$this->list_pages_select($dat['PAGEID'],"pageId"));
			$_[] = $h->p($t->wr("type").$h->input("text","type",$dat['TYPEPAGE'],"readonly").$t->wlr("param").$h->input("text","param",$dat['PAGEID'],"readonly"),"style='color:grey'");
			$_[] = $h->p($t->wr("website administrator mail").$h->input("text","mail",$dat['MAIL']));
			$_[] = $h->p($h->input("submit","save",$t->w("update all")));
			$inputs = implode("",$_);
			return $h->form($inputs,"home","post","admin.php?action=admin_home");
		}
	}
	public function update_site_params(){
		if ($_POST['param']) {
			$paramId = $_POST['param'];
		} else {
			$paramId = $_POST['pageId'];
		}
		$query = UPDATE.PARAMS.
					SET."PAGEID = '".$this->h->word($paramId).
					"',TYPEPAGE = '".$this->h->word($_POST['type']).
					"',NAVTYPE = '".$this->h->word($_POST['navtype']).
					"',MAIL = '".$this->h->safe($_POST['mail'])."'".
				WHERE."ID = 1";
		$query = $this->q($query);
		return $this->h->h3($this->t->w("some values have been modified !"),"class='warning'");
	}
	public function list_pages_select($pageId,$name){
		$query = SELECT.PAGES.".ID,".PAGES.".NAME,".PAGES.".TYPEPAGE".FROM.PAGES;
		$query = $this->q($query);
		$options = array();
		while ( $line = $this->fetch($query) ){
			if ($line['ID'] == $pageId){
				$optionSelectect = "k=".$line['TYPEPAGE']."&amp;v=".$line['ID'];
				$options[$line['NAME']] = "k=".$line['TYPEPAGE']."&amp;v=".$line['ID'];
			} else {
				$options[$line['NAME']] = "k=".$line['TYPEPAGE']."&amp;v=".$line['ID'];
			}
		}
		return $this->h->select($options,$name,$optionSelectect,"onchange='fillHomeFields(this.value)'");
	}
}
?>
